@@ -7,7 +7,7 @@ use warnings 'all';
 ###########################################################################
 # METADATA
 our $AUTHORITY = 'cpan:DOUGDUDE';
-our $VERSION   = '0.13_002';
+our $VERSION   = '0.13_003';
 
 ###########################################################################
 # MOOSE
@@ -407,6 +407,18 @@ sub _parse_response_body {
 		${$status_r} = to_Status($1);
 	}
 
+	if (!defined ${$status_r} && $response->headers->content_is_html) {
+		# This is HTML, so what we will do is strip all surrounding tags
+		# since it looks like a valid status wasn't found
+		${$message_r} =~ s{\s* < [^>]+ > \s*}{}msx; # XXX: Fix me later
+
+		# Reparse for the status code
+		if (${$message_r} =~ m{\A (?:[^a-z]+ \s+)? (OK|WARNING|CRITICAL|UNKNOWN)}msx) {
+			# Found the status
+			${$status_r} = to_Status($1);
+		}
+	}
+
 	if (${$message_r} =~ m{\|}msx) {
 		# Looks like there is performance data to parse somewhere
 		my @message_lines = split m{[\r\n]{1,2}}msx, ${$message_r};
@@ -583,7 +595,7 @@ Nagios::Plugin::OverHTTP - Nagios plugin to check over the HTTP protocol.
 
 =head1 VERSION
 
-Version 0.13_002
+Version 0.13_003
 
 =head1 SYNOPSIS
 
